# Find one or more file(s) in a list of dirs
AC_DEFUN(AC_FIND_FILE,
[
$3=NO
for i in $2;
do
  for j in $1;
  do
    if test -r "$i/$j"; then
      $3=$i
      break 2
    fi
  done
done
])

AC_DEFUN(AC_MY_PATH_X,
[
AC_MSG_CHECKING(for X)
AC_CACHE_VAL(ac_cv_have_x,
[# One or both of the vars are not set, and there is no cached value.
ac_x_includes=NO ac_x_libraries=NO
AC_PATH_X_DIRECT
AC_PATH_X_XMKMF
if test "$ac_x_includes" = NO || test "$ac_x_libraries" = NO; then
  AC_MSG_ERROR([Can't find X. Please add the correct paths. View configure --help for usage!])
else
  # Record where we found X for the cache.
  ac_cv_have_x="have_x=yes \
                ac_x_includes=$ac_x_includes
ac_x_libraries=$ac_x_libraries"
fi])dnl
eval "$ac_cv_have_x"
 
if test "$have_x" != yes; then
  AC_MSG_RESULT($have_x)
  no_x=yes
else
  # If each of the values was on the command line, it overrides each guess.
  test "x$x_includes" = xNONE && x_includes=$ac_x_includes
  test "x$x_libraries" = xNONE && x_libraries=$ac_x_libraries
  # Update the cache value to reflect the command line values.
  ac_cv_have_x="have_x=yes \
                ac_x_includes=$x_includes ac_x_libraries=$x_libraries"
  AC_MSG_RESULT([libraries $x_libraries, headers $x_includes])
fi

if test -z "$x_includes" || test "x$x_includes" = xNONE; then
  X_INCLUDES=""
  x_includes="."; dnl better than nothing :-
 else
  X_INCLUDES="-I$x_includes"
fi

if test -z "$x_libraries" || test "$x_libraries" = xNONE; then
  X_LDFLAGS=""
  x_libraries="/usr/lib"; dnl better than nothing :-
  all_libraries=""
 else
  X_LDFLAGS="-L$x_libraries"
  all_libraries=$X_LDFLAGS
fi

AC_SUBST(x_includes)
AC_SUBST(x_libraries)
])

# Find Qt include & library directories.
AC_DEFUN(AC_PATH_QT,
[
dnl Checking for Qt...
AC_MSG_CHECKING([for Qt])

dnl We suppose that we don't have found anything
ac_qt_includes=NO ac_qt_libraries=NO
qt_lib=""
qt_inc=""

dnl We look in the cache
AC_CACHE_VAL(ac_cv_have_qt,
[
dnl We look for include files in these directories
qt_incdirs="/usr/lib/qt/include /usr/local/qt/include /usr/include/qt /usr/include /usr/X11R6/include/X11/qt /usr/X11R6/include/qt $x_includes $QTINC"
test -n "$QTDIR" && qt_incdirs="$QTDIR/include $QTDIR $qt_incdirs"
AC_FIND_FILE(qslider.h, $qt_incdirs, qt_incdir)
ac_qt_includes=$qt_incdir

dnl We look for the library in these directories
qt_libdirs="/usr/lib/qt/lib /usr/local/qt/lib /usr/lib/qt /usr/lib /usr/X11R6/lib $x_libraries $QTLIB"
test -n "$QTDIR" && qt_libdirs="$QTDIR/lib $QTDIR $qt_libdirs"
AC_FIND_FILE(libqt.so libqt.a libqt.sl, $qt_libdirs, qt_libdir)
ac_qt_libraries=$qt_libdir

# We write the result
if test "$ac_qt_includes" = NO || test "$ac_qt_libraries" = NO; then
  ac_cv_have_qt="have_qt=no"
  ac_qt_notfound=""
  if test "$ac_qt_includes" = NO; then
    if test "$ac_qt_libraries" = NO; then
      ac_qt_notfound="(headers and libraries)";
    else
      ac_qt_notfound="(headers)";
    fi
  else
    ac_qt_notfound="(libraries)";
  fi
  AC_MSG_ERROR([QT1.2 $ac_qt_notfound not found...]);
else
  ac_cv_have_qt="have_qt=yes \
  ac_qt_includes=$ac_qt_includes ac_qt_libraries=$ac_qt_libraries"
fi])dnl

# We parse the result from the cache
eval "$ac_cv_have_qt"
if test "$have_qt" != yes; then
  AC_MSG_RESULT([$have_qt]);
else
  ac_cv_have_qt="have_qt=yes \
    ac_qt_includes=$ac_qt_includes ac_qt_libraries=$ac_qt_libraries"
  AC_MSG_RESULT([libraries $ac_qt_libraries, headers $ac_qt_includes])
  
  qt_inc=$ac_qt_includes
  qt_lib=$ac_qt_libraries
fi
AC_SUBST(qt_inc)
AC_SUBST(qt_lib)
])

# Find Python include & library directories.
AC_DEFUN(AC_PATH_PYTHON,
[
dnl Checking for Python...
AC_MSG_CHECKING([for Python])

AC_CACHE_VAL(ac_cv_have_python,
[
eval "echo -n Enter the Python top level directory: "
eval "read toplevel"

ac_cv_have_python="have_python=yes \
  toplevel=$toplevel"
])

eval "$ac_cv_have_python"
AC_MSG_RESULT([found in $toplevel])
python_inc=$toplevel
python_lib=$toplevel
PYTHON_INC="-I$python_inc -I$python_inc/Include"
PYTHON_LIB="$python_lib/Modules/timemodule.o $python_lib/Modules/stropmodule.o $python_lib/Modules/regexpr.o $python_lib/Modules/regexmodule.o $python_lib/Modules/config.o $python_lib/Modules/getpath.o $python_lib/Modules/libModules.a $python_lib/Python/libPython.a $python_lib/Objects/libObjects.a $python_lib/Parser/libParser.a"
AC_SUBST(PYTHON_INC)
AC_SUBST(PYTHON_LIB)
])
