/*
 *  ChannelWindow.h - The window type for channels
 *  Copyright (c) 1997 Etienne Bernard (eb@via.ecp.fr)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef CHANNELWINDOW_H

#define CHANNELWINDOW_H

#include "LoggingWindow.h"
#include "User.h"

#include <qlistbox.h>
#include <qlist.h>
#include <qpopmenu.h>
#include <String.h>


class ChannelWindow : public LoggingWindow
{
public:
  ChannelWindow(String);
  ~ChannelWindow();

  // Nicklist operations
  void addNick(String, int pos=-1);
  bool hasNick(String);
  void delNick(String);
  void clearNicks();
  void changeNick(String, String);
  int findNick(String nick);

  // Users & channel operations
  void setOper(String, bool);
  bool isOper(String);
  void setVoice(String, bool);
  void parseMode(String, String);
  void setTopic(String);

  // Window status
  int getStatus(void) { return status; }
  void setStatus(int s) { status = s; }

  enum {
    JOINING, AFTER_NAMES, KICKED
  };

  enum {
    PRIVATE = 1, SECRET = 2, INVITE_ONLY = 4, TOPIC_RESTRICTED = 8,
    EXTMSG_RESTRICTED = 16, MODERATED = 32
  };

  static QPopupMenu *rightMenu;

protected:
  void newTitle(void);
  void handleInput();

  void resizeEvent(QResizeEvent *re);
  bool eventFilter(QObject *, QEvent *);

private:
  QListBox *nickListBox;
  QList<User> nickList;

  String topic;
  String key;
  int limit;
  int mode;
  int status;
};

#endif
