/*
 *  LineEdit.h - A customizable line editor, based on Qt's line editor.
 *  Copyright (c) 1997 Etienne Bernard (eb@via.ecp.fr)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef LINEEDIT_H
#define LINEEDIT_H

#include <String.h>

#include <qwidget.h>

static const int blinkTime = 500;
static const int scrollTime = 100;

class LineEdit : public QWidget
{
    Q_OBJECT

public:
    LineEdit(QWidget *parent=0, const char *name=0);
   ~LineEdit();

    const char *text() const;

    int maxLength() const;
    void setMaxLength(int);

public slots:
    void setText(const char *);

signals:
    void textChanged(const char *);
    void returnPressed();

protected:
    void cursorLeft(int steps = 1);
    void cursorRight(int steps = 1);
    void backspace();
    void del();
    void begin();
    void end();

protected:
    void keyPressEvent(QKeyEvent *);
    void focusInEvent(QFocusEvent *);
    void focusOutEvent(QFocusEvent *);
    void paintEvent(QPaintEvent *);
    void resizeEvent(QResizeEvent *);

private:
    String buf;
    int cursorPos;
    int maxLen;
    int offset;
};

#endif
