/*
 *  PyIRC.h - The main object.
 *  Copyright (c) 1997 Etienne Bernard (eb@via.ecp.fr)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef PYIRC_H

#define PYIRC_H

#include "Window.h"
#include "ChannelWindow.h"
#include "MessageWindow.h"
#include "Server.h"
#include "ConnectDialog.h"
#include "LinksWindow.h"
#include "Parser.h"

#include <qwidget.h>
#include <qmenubar.h>
#include <qlist.h>
#include <qsocknot.h>

#include <time.h>

class PyIRC : public Window
{
  Q_OBJECT

public:
  PyIRC(QWidget *parent=0, const char *name=0);
  ~PyIRC();

  Window * findWindow(String);
  MessageWindow * addMessageWindow(String);
  ChannelWindow * addChannelWindow(String);

  void parseCommandLine(int argc, char *argv[]);
  void readConfigFile(void);
  void loadBookmarks(void);
  void loadScript(String filename);
  void loadInitFile(void);

  int getSock(void);
  void setNickname(String);
  void setUsername(String);
  void setIrcname(String);
  void setServer(Server *);
  bool isOnChannel(String);

  void ircConnect(void);
  void ircDisconnect(void);

  void parseMode(String);

  bool connected, registered;
  QList<Window> windowList;
  LinksWindow *linksWindow;
  Parser *parser;

  enum {
    IRCOP = 1, WALLOPS = 2, SERVNOTICES = 4, INVISIBLE = 8
  };

protected:
  void closeEvent(QCloseEvent *);

  void newTitle(void);

public slots:
  void FileConnect();
  void FileDisconnect();
  void FileQuit();
  void BookmarksSave();
  void DccSend();
  void DccChat();
  void DccOptions();
  void HelpAbout();
  void HelpLicense();
  void HelpUsing();
  void HelpScripts();

  void closedChild(Window *);
  void update_idle();
  time_t idle_time();

protected slots:
  void readData();
  void writeData();
  void handleInput();
  void channelBookmarkSelected(int);
  void queryBookmarkSelected(int);

protected:
  int mode;
  QMenuBar *menu;
  QPopupMenu *channelBookmarks, *queryBookmarks;
  ConnectDialog *fileConnect;

private:
  static String configFile, bookFile, initFile;
  String nick, username, ircname;
  Server server;
  QSocketNotifier *readSocketNotifier, *writeSocketNotifier;
  time_t idle;
};

#endif
