#include <qlabel.h>
#include <qpushbt.h>

#include "AskDialog.h"

AskDialog::AskDialog(String titlestr, String textstr, bool password,
                     QWidget *parent, const char *name)
  : QDialog(parent, name, TRUE)
{
  int w = 0, h = 0;

  setCaption(titlestr.chars());

  QLabel *label = new QLabel(this, "label");
  label->setText(textstr.chars());
  label->setAlignment(AlignCenter);

  QPushButton *okButton = new QPushButton("Ok", this, "ok button");
  connect(okButton, SIGNAL(clicked()), SLOT(accept()));
  okButton->setDefault(TRUE);

  lineEdit = new QLineEdit(this, "line edit");
  lineEdit->setFocus();
  if (password)
    lineEdit->setEchoMode(QLineEdit::Password);
  connect(lineEdit, SIGNAL(returnPressed()), SLOT(accept()));

  QPushButton *cancelButton = new QPushButton("Cancel", this,
                                   "cancel button");
  connect(cancelButton, SIGNAL(clicked()), SLOT(reject()));
//  cancelButton->setDefault(FALSE);
  cancelButton->setAutoDefault(TRUE);

  QFont font("Helvetica", 12);
  label->setFont(font);
  lineEdit->setFont(font);
  font.setWeight(QFont::Bold);
  okButton->setFont(font);
  cancelButton->setFont(font);

  label->adjustSize();
  QSize okSize = okButton->sizeHint(),
        cancelSize = cancelButton->sizeHint();
  w = QMAX(okSize.width(), cancelSize.width());
  h = QMAX(okSize.height(), cancelSize.height());
  okButton->resize(w, h);
  cancelButton->resize(w,h);
  QFontMetrics fm = label->fontMetrics();
  lineEdit->resize(label->width(), fm.height()+6);
  w = QMAX(2*w, label->width());
  w += 10;
  QString s = label->text();
  h = h + 20 + lineEdit->height() + fm.lineSpacing() *
      (s.contains('\n')+1);

  setFixedSize(w, h);

  label->move(width()/2 - label->width()/2, 5);
  lineEdit->move(width()/2 - label->width()/2, label->height() + 10);
  okButton->move((width() - 2 * okButton->width()) / 3,
                 height() - 5 - okButton->height());
  cancelButton->move((2 * width() -  okButton->width()) / 3,
                 height() - 5 - okButton->height());
}

String
AskDialog::getResult(void)
{
  return String(lineEdit->text());
}
