/*
 *  FontSelector.cpp - The font selection dialog box
 *  Copyright (c) 1997 Etienne Bernard (eb@via.ecp.fr)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <qlabel.h>
#include <X11/Xlib.h>

#include "FontSelector.h"

FontSelector::FontSelector(QWidget *parent,
  const char *name) : QDialog(parent, name, TRUE)
{
  QLabel *anyLabel;

  anyLabel = new QLabel(this, "family label");
  anyLabel->setText("Family:");
  anyLabel->setGeometry(10, 10, 50, 20);

  familyBox = new QListBox(this, "family selector");
  familyBox->setGeometry(10, 30, 140, 120);
  connect(familyBox, SIGNAL(highlighted(int)), this, SLOT(repaintText()));

  anyLabel = new QLabel(this, "size label");
  anyLabel->setText("Size:");
  anyLabel->setGeometry(160, 10, 40, 20);

  sizeBox = new QListBox(this, "size selector");
  sizeBox->insertItem("8");
  sizeBox->insertItem("9");
  sizeBox->insertItem("10");
  sizeBox->insertItem("11");
  sizeBox->insertItem("12");
  sizeBox->insertItem("13");
  sizeBox->insertItem("14");
  sizeBox->insertItem("15");
  sizeBox->insertItem("16");
  sizeBox->setGeometry(160, 30, 40, 120);
  connect(sizeBox, SIGNAL(highlighted(int)), this, SLOT(repaintText()));

  anyLabel = new QLabel(this, "style label");
  anyLabel->setText("Style:");
  anyLabel->setGeometry(210, 10, 50, 20);

  styleBox = new QListBox(this, "style selector");
  styleBox->insertItem("Normal");
  styleBox->insertItem("Italic");
  styleBox->insertItem("Bold");
  styleBox->insertItem("Bold italic");
  styleBox->setGeometry(210, 30, 80, 60);
  connect(styleBox, SIGNAL(highlighted(int)), this, SLOT(repaintText()));

  anyLabel = new QLabel(this, "text display label");
  anyLabel->setText("Sample text:");
  anyLabel->setGeometry(10, 160, 80, 20);

  textDisplay = new QLabel(this, "text display");
  textDisplay->setGeometry(10, 180, 190, 50);
  textDisplay->setAlignment(AlignCenter);;
  textDisplay->setBackgroundColor(white);
  textDisplay->setText("aAbB... PyIRC... yYzZ");

  ok = new QPushButton("Ok", this);
  ok->setDefault(TRUE);
  ok->setGeometry(220, 175, 70, 25);
  connect(ok, SIGNAL(clicked()), this, SLOT(accept()));

  cancel = new QPushButton("Cancel", this);
  cancel->setGeometry(220, 205, 70, 25);
  connect(cancel, SIGNAL(clicked()), this, SLOT(reject()));

  setCaption("Font selection");
  setFixedSize(300, 240);

  String temp;
  Display *d = this.x11Display();
  int count;
  char **list = XListFonts(d, "-*-*-*-*-*-*-*-*-*-*-*-*-iso8859-*",
                  32768, &count);
  for (int i = 0; i < count; i++) {
    temp = list[i];
    temp = temp.after("-");
    temp = temp.after("-");
    temp = temp.before("-");

    if (families.find(capitalize(temp)) == -1)
      families.inSort(capitalize(temp));
  }

  for (unsigned i = 0; i < families.count(); i++)
    familyBox->insertItem(families.at(i));
}

FontSelector::~FontSelector()
{
}

void
FontSelector::setFont(const QFont &font)
{
  int i;
  QFontInfo fi(font);

  i = families.find(capitalize(fi.family()));
  familyBox->setCurrentItem(i);
  familyBox->setTopItem(i);
  sizeBox->setCurrentItem(fi.pointSize()-8);
  styleBox->setCurrentItem(fi.bold()*2+fi.italic());
}

const QFont &
FontSelector::getFont(void)
{
  return textDisplay->font();
}

void
FontSelector::repaintText()
{
  QFont font(families.at(familyBox->currentItem()),
             sizeBox->currentItem()+8,
             styleBox->currentItem()>=2 ? QFont::Bold : QFont::Normal,
             styleBox->currentItem() % 2);
  textDisplay->setFont(font);
}
