/*
 *  LoggingWindow.cpp - Windows that are capable of logging
 *  Copyright (c) 1997 Etienne Bernard (eb@via.ecp.fr)
 *  
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <qfiledlg.h>

#include "LoggingWindow.h"
#include "FontSelector.h"
#include "PyIRC.h"
#include "Util.h"

extern PyIRC *mainWindow;

LoggingWindow::LoggingWindow(String name)
  : Window(name), logfilename(""), logging(FALSE), file(0), options(0), 
    menu(0)
{
  initMetaObject();
  file = new QPopupMenu;
  file->insertItem("&Start new log...", this, SLOT(setLogOn()));
  file->setItemEnabled(file->insertItem("&Close log", this,
    SLOT(setLogOff())), FALSE);
  file->insertSeparator();
  file->insertItem("Close &window", this, SLOT(closeMe()));
  file->insertSeparator();
  file->insertItem("&Quit PyIRC", mainWindow, SLOT(FileQuit()));

  options = new QPopupMenu;
  CHECK_PTR(options);
  options->insertItem("&Colors...", this, SLOT(OptionsColors()));
  options->insertItem("&Font...", this, SLOT(OptionsFont()));

  menu = new QMenuBar(this);
  menu->insertItem("&File", file);
  menu->insertItem("&Options", options);
}

LoggingWindow::~LoggingWindow()
{
  delete file;
  delete menu;
  if (logging)
    logfile.close();
}

void
LoggingWindow::insertLine(String s)
{
  if (logging)
    logfile << Util::removeNonAlpha(s) << endl;
    
  Window::insertLine(s);
}

void
LoggingWindow::setLogOn(void)  
{
  logfilename = QFileDialog::getSaveFileName(0, "*.log");
  if (logfilename.isEmpty())
    return;
  logfile.open((const char *)logfilename, ios::out | ios::trunc);
  if (!logfile)
    abort();
  logging = TRUE;
  insertLine(String("*** Logging started on ") +
    Util::timeStr(time(NULL)));
  file->setItemEnabled(file->idAt(0), FALSE);
  file->setItemEnabled(file->idAt(1), TRUE); 
}
 
void
LoggingWindow::setLogOff(void)
{
  insertLine(String("*** Logging stopped on ") +
    Util::timeStr(time(NULL)));
  logfile.close();
  logging = FALSE;
  file->setItemEnabled(file->idAt(0), TRUE);
  file->setItemEnabled(file->idAt(1), FALSE);
}

void
LoggingWindow::closeMe(void)
{
  close();
}

