/*
 *  main.cpp - The main() function
 *  Copyright (c) 1997 Etienne Bernard (eb@via.ecp.fr)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <Python.h>
#include <Integer.h>

#include <signal.h>
#include <iostream.h>
#include <qapp.h>

#include <pwd.h>
#include <sys/types.h>
#include <unistd.h>
#include <signal.h>

#include "PyIRC.h"
#include "Util.h"
#include "Defines.h"
#include "FontSelector.h"

PyIRC *mainWindow;
PyObject *globalDict;

extern void initrawmodule(void);
extern "C" void initregex(void);
extern "C" void initstrop(void);
extern "C" void inittime(void);

QApplication *app;

void
sig_alarm(int)
{
  time_t t = time(0);
  int it = mainWindow->idle_time();
  struct tm * time_val = localtime(&t);

  if (time_val->tm_sec == 0) {
    char buf[6];
    sprintf(buf, "%02d:%02d", time_val->tm_hour, time_val->tm_min);
    Util::do_on(2, "TIMER", buf);
#ifdef DBG
    cout << "ON TIMER " << buf << endl;
#endif
  }

  if ((t - it) % 60 == 0) {
    Util::do_on(2,"IDLE", dec((t - it)/60));
#ifdef DBG
    cout << "ON IDLE " << (t - it) / 60 << endl;
#endif
    alarm(60-time_val->tm_sec);
  } else
    alarm(QMIN(60-time_val->tm_sec, 60 - (t - it)%60));

  signal(SIGALRM, sig_alarm);
}

void sig_int(int)
{
  if (mainWindow && mainWindow->registered)
    Util::send(mainWindow->getSock(), "QUIT :Grr, SIGINT");
  app->quit();
}

void sig_segv(int)
{
  if (mainWindow && mainWindow->registered)
    Util::send(mainWindow->getSock(), "QUIT :Oops, SIGSEGV");
  cout << "Hey, you've found a bug. If you can reproduce it, please send" 
       << endl << "a bug report to the author, explaining what you did."
       " Please" << endl << "ensure that you have the latest version."
       << endl;
  abort();
}

int main(int argc, char *argv[]) {
  
  cout << "PyIRC version " << VERSION_NUMBER << endl;
  cout << "Copyright (c) 1997 Etienne BERNARD" << endl;
  cout << "This is free software, and you are welcome to redistribute it\n";
  cout << "under certain conditions; see Help/License for details.\n";

  Py_Initialize();

  signal(SIGINT, SIG_DFL);
  signal(SIGALRM, sig_alarm);
  alarm(30);
  signal(SIGINT, sig_int);
#ifndef DBG
  signal(SIGSEGV, sig_segv);
#endif

  initrawmodule();
  inittime();
  initstrop();
  initregex();

  mainWindow->loadScript(STDSCRIPT);

  PyObject *m = PyImport_AddModule("__main__");
  globalDict = PyModule_GetDict(m);

  app = new QApplication(argc, argv);

  app->setStyle(WindowsStyle);

  mainWindow = new PyIRC();

  // We parse the remaining arguments
  mainWindow->parseCommandLine(argc, argv);
  
  app->setMainWidget(mainWindow);
  mainWindow->show();

  mainWindow->FileConnect();

  int r = app->exec();
  delete app;
  return r;
}
