/*
 *  MessageWidget.cpp - The widget used for message display
 *  Copyright (c) 1997 Etienne Bernard (eb@via.ecp.fr)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <qpixmap.h>
#include <qpainter.h>

#include "MessageWidget.h"

/*
QColor
  MessageWidget::Colors[16] = { QColor(255, 255, 255),
                                QColor(000, 000, 000),
                                QColor(000, 000, 128),
                                QColor(000, 128, 000),
                                QColor(255, 000, 000),
                                QColor(128, 064, 000),
                                QColor(128, 000, 128),
                                QColor(255, 128, 064),
                                QColor(255, 255, 000),
                                QColor(000, 255, 128),
                                QColor(000, 128, 128),
                                QColor(000, 255, 255),
                                QColor(000, 000, 255),
                                QColor(255, 000, 255),
                                QColor(128, 128, 128),
                                QColor(192, 192, 192) };
*/

MessageWidget::MessageWidget(QWidget *parent, char *name)
  : QTableView(parent, name)
{
  fm = new QFontMetrics(fontMetrics());

  setFocusPolicy(NoFocus);
  setBackgroundColor(colorGroup().base());
  setAutoUpdate(TRUE);
  setNumCols(1);
  setNumRows(0);
  setCellWidth(1);
//setCellHeight(fm->lineSpacing());
  setCellHeight(fm->height()-1);
  setFrameStyle(QFrame::WinPanel | QFrame::Sunken);
  setTableFlags(Tbl_autoVScrollBar | Tbl_autoHScrollBar |
                Tbl_smoothVScrolling | Tbl_clipCellPainting);
  line_y = 0;
  _width = 1;
}

MessageWidget::~MessageWidget()
{
  linebuffer.clear();
}

void
MessageWidget::clear(void)
{
  linebuffer.clear();
  setNumRows(0);
  _width = 1;
  repaint();
}

int
MessageWidget::numLines(void) const
{
  return linebuffer.count();
}

void
MessageWidget::insertLine(String s)
{
  if (s.length()!=0) {
    linebuffer.append(s);
    if (fm->width(s) > _width-1)
      _width = fm->width(s)+1;
    setCellWidth(_width);
    setNumRows(linebuffer.count());

    updateCell(line_y, 0, TRUE);
    line_y++;

    setPositionToEnd();
  }
}

void
MessageWidget::setFont(const QFont &font)
{
  QWidget::setFont(font);
  
  delete fm;
  fm = new QFontMetrics(font);
//  setCellHeight(fm->lineSpacing() + 1);
  setCellHeight(fm->height() - 1);
}

void
MessageWidget::setPositionToEnd(void)
{
  setYOffset(maxYOffset());
  repaint();
}

void
MessageWidget::paintCell(QPainter *painter, int row, int)
{
    QRect updateRect = cellUpdateRect();

    if (updateRect.width() <= 0 || updateRect.height() <= 0)
      return;

    QPixmap *buffer = new QPixmap(updateRect.size());
    if (buffer == 0 || buffer->isNull())
      return;

    QColorGroup cg = colorGroup();
    QColor fg = cg.text(), bg = cg.base();
    QFont fnt = painter->font();
    QFontMetrics fm(fnt);
    QPainter p;
    String str = linebuffer.at(row), s, t;
    int pos = 1;
    bool reverse = FALSE;

    buffer->fill(cg.base());
    p.begin(buffer);

    p.setBackgroundMode(OpaqueMode);
    p.translate(-updateRect.left(), -updateRect.top());

    while (str != "") {
      s = "";
      while (str != "" && str[0]=='@' && str.length()>1) {
        switch(str[1]) {
          case 'u':
//            fnt.setUnderline(!fnt.underline());
            fnt.setItalic(!fnt.italic());
            break;
          case 'r':
            if (reverse) {
              p.setPen(fg);
              p.setBackgroundColor(bg);
            } else {
              p.setPen(bg);
              p.setBackgroundColor(fg);
            }
            reverse = !reverse;
            break;
          case 'b':
            fnt.setBold(!fnt.bold());
            break;
          case '@': s += '@';
             str = str.after(1);
             goto end; // Sorry
        }
        str = str.after(1);
      }

end:
      t = str.before("@");
      if (t == "")
        s += str;
      else
        s += t;
      str = str.after(str.index("@")-1);

      p.setFont(fnt);
      p.drawText(pos, fm.ascent()-1, s.chars());
      pos += fm.width(s.chars());
    }
  p.end();
  painter->drawPixmap(updateRect.left(), updateRect.top(), *buffer);
  delete buffer;
}
