#include <Python.h>
#include <cgensupport.h>

#include <qapp.h>

#include <ctype.h>

#include "PyIRC.h"
#include "Util.h"

extern PyIRC *mainWindow;
extern PyObject *windowName, *nickName;

Window
*currentWindow(void)
{
  char *buf;
  PyArg_GetString(windowName, 1, 0, &buf);
  return mainWindow->findWindow(buf);
}

static PyObject *
raw_open(PyObject *self, PyObject *args)
{
  char *s = "-";

  if (!PyArg_ParseTuple(args, "s", &s))
    return 0;

  Window *w = mainWindow->findWindow(s);
  if (w == 0) {
    if (Util::isChannelName(s))
      w = mainWindow->addChannelWindow(s);
    else
      w = mainWindow->addMessageWindow(s);
  }
  w->show();

  Py_INCREF(Py_None);
  return Py_None;
}

static PyObject *
raw_close(PyObject *self, PyObject *args)
{
  char *s;

  if (!PyArg_ParseTuple(args, "s", &s))
    return 0;

  Window *w = mainWindow->findWindow(s);
  if (w == 0)
    mainWindow->insertLine(String("*** ") + s + " : No such window.");
  else
    mainWindow->closedChild(w);

  Py_INCREF(Py_None);
  return Py_None;
}

static PyObject *
raw_exist(PyObject *self, PyObject *args)
{
  char *s;

  if (!PyArg_ParseTuple(args, "s", &s))
    return 0;

  Window *w = mainWindow->findWindow(s);

  if (w == 0) {
    Py_INCREF(Py_True);
    return Py_True;
  }

  Py_INCREF(Py_False);
  return Py_False;
}

static PyObject *
raw_hasnick(PyObject *self, PyObject *args)
{
  char *c, *n;

  if (!PyArg_ParseTuple(args, "ss", &c, &n))
    return 0;

  if (Util::isChannelName(c)) {
    Py_INCREF(Py_False);
    return Py_False;
  }

  ChannelWindow *w = (ChannelWindow *)mainWindow->findWindow(c);
  if (w == 0 || !w->hasNick(n)) {
    Py_INCREF(Py_False);
    return Py_False;
  }

  Py_INCREF(Py_True);
  return Py_True;
}

static PyObject *
raw_ischanop(PyObject *self, PyObject *args)
{
  char *c = "", *n = "";

  if (!PyArg_ParseTuple(args, "ss", &c, &n))
    return 0;

  if (!Util::isChannelName(c)) {
    Py_INCREF(Py_False);
    return Py_False;
  }

  ChannelWindow *w = (ChannelWindow *)mainWindow->findWindow(c);
  if (w == 0 || !w->hasNick(n)) {
    Py_INCREF(Py_False);
    return Py_False;
  }

  if (w->isOper(n)) {
    Py_INCREF(Py_True);
    return Py_True;
  }

  Py_INCREF(Py_False);
  return Py_False;
}

static PyObject *
raw_clear(PyObject *self, PyObject *args)
{
  char *s = "";

  if (!PyArg_ParseTuple(args, "|s", &s))
    return 0;

  if (s[0]=='\0')
    currentWindow()->clear();
  else {
    Window * w = mainWindow->findWindow(s);
    if (w == 0)
      currentWindow()->insertLine(String("*** No such window : ") + s);
    else
      w->clear();    
  }

  Py_INCREF(Py_None);
  return Py_None;
}

static PyObject *
raw_send(PyObject *self, PyObject *args)
{
  char *s; int sock;

  if (mainWindow->getSock() < 0) {
    mainWindow->insertLine("*** Not connected.");
    Py_INCREF(Py_None);
    return Py_None;
  }

  sock = mainWindow->getSock();

  if (!PyArg_ParseTuple(args, "s|i", &s, &sock))
    return 0;

  Util::send(sock, s);

  Py_INCREF(Py_None);
  return Py_None;
}

static PyObject *
raw_echo(PyObject *self, PyObject *args)
{
  char *s, *win = "-";
  Window *w;

  if (!PyArg_ParseTuple(args, "s|s", &s, &win))
    return 0;

  w = mainWindow->findWindow(win);
  if (w == 0) {
    mainWindow->insertLine(String("*** No such window : ") + win);
    Py_INCREF(Py_None);
    return Py_None;
  }

  w->insertLine(s);
  Py_INCREF(Py_None);
  return Py_None;
}

static PyObject *
raw_beep(PyObject *self, PyObject *args)
{
  extern QApplication * app;

  app->beep();
  Py_INCREF(Py_None);
  return Py_None;
}

static PyObject *
raw_load(PyObject *self, PyObject *args)
{
  char *s = "";

  if (!PyArg_ParseTuple(args, "s", &s))
    return 0;

  mainWindow->loadScript(s);

  Py_INCREF(Py_None);
  return Py_None;
}

static PyObject *
raw_getstring(PyObject *self, PyObject *args)
{
  char *title = "", *text = "";
  int pass = FALSE;

  if (!PyArg_ParseTuple(args, "ssi", &title, &text, &pass))
    return 0;

  return PyString_FromString((char *)(Util::getString(title,
    text, pass)).chars());
}

static PyMethodDef raw_methods[] = {
	{ "clear",	raw_clear,		1 },
	{ "echo",	raw_echo,		1 },
        { "send",       raw_send,	     	1 },
        { "beep",       raw_beep,	     	1 },
	{ "open",	raw_open,		1 },
	{ "close",	raw_close,		1 },
	{ "exist",	raw_exist,		1 },
	{ "hasnick",	raw_hasnick,		1 },
	{ "ischanop",	raw_ischanop,		1 },
	{ "load",	raw_load,		1 },
	{ "getstring",	raw_getstring,		1 },
        { NULL,         NULL }
};

void
initrawmodule()
{
  Py_InitModule("raw", raw_methods);
  PyObject *o = PyImport_AddModule("raw");
  PyObject *p = PyModule_GetDict(o);
  nickName = PyString_FromString("");
  PyDict_SetItemString(p, "nickname", nickName);
}
