/*
 *  Window.cpp - Base type for windows
 *  Copyright (c) 1997 Etienne Bernard (eb@via.ecp.fr)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <Python.h>

#include <qfont.h>

#include <String.h>

#include "Window.h"
#include "FontSelector.h"
#include "PyIRC.h"
#include "Util.h"

extern PyIRC *mainWindow;

Window::Window(String n)
  : QWidget(), messageArea(0), messageEdit(0), _name(n)
{
  initMetaObject();

  messageArea = new MessageWidget(this, "MessageArea");
  if (messageArea == 0)
    abort();
  messageArea->setGeometry(0, 30, 500, 310);

  messageEdit = new QLineEdit(this, "MessageEdit");
  if (messageEdit == 0)
    abort();
  messageEdit->setGeometry(0, 340, 500, 22);
  messageEdit->setText("");
  messageEdit->setMaxLength(450);
  messageEdit->setEchoMode(QLineEdit::Normal);
  messageEdit->setFrame(TRUE);
  messageEdit->setFocus();
  connect(messageEdit, SIGNAL(returnPressed()), SLOT(handleInput()));
  if (mainWindow != 0)
    connect(messageEdit, SIGNAL(textChanged(const char*)), mainWindow,
        SLOT(update_idle()));

  resize(500,362);
  setMinimumSize(385, 225);

  setFont(QFont("Courier"));
  setCaption(_name);
}

Window::~Window()
{
  delete messageArea;
  delete messageEdit;
}

void
Window::clear(void) const
{
  messageArea->clear();
}

void
Window::insertLine(String s)
{
  messageArea->insertLine(Util::convertToAlpha(s));
}

void
Window::setFont(const QFont &font)
{
  messageArea->setFont(font);
  messageEdit->setFont(font);
}

String
Window::getName(void)
{
  return _name;
}

void
Window::resizeEvent(QResizeEvent *re)
{
  messageArea->resize(re->size().width(),
                      re->size().height() - 52);
  messageEdit->setGeometry(0, re->size().height() - 22,
                           re->size().width(), 22);
  messageArea->setPositionToEnd();
}

void
Window::closeEvent(QCloseEvent *e)
{
  e->accept();
  emit windowClosed(this);
} 

void
Window::OptionsColors() {
} 

void
Window::OptionsFont() {
  FontSelector *fontSelector = new FontSelector(this);  
  fontSelector->setFont(messageArea->font());
  if (fontSelector->exec())
    Window::setFont(fontSelector->getFont());
  delete fontSelector;
}

